Mini, Discreet And Comfortable Ear Hearing Aid.
Author: Active Mobility
Description: Unlike many other hearing devices that are worn behind the ear, the Mini Ear fits discreetly and comfortable intoyour ear. You’ll forget it’s even there!
Keywords: default key words

- Change text size:

My shopping basket
0 items | £0.00

Login | Register

Active Mobility Centre
For help and information call 01642 805050

## VAT Exempt Pricing

## Ordering and Pricing Options

We are able to sell many of our products without VAT to those eligible for VAT relief. Click here for more information
We accept online and offline orders from individuals and official bodies with a variety of payment methods. Click here for more information.
Hide
Tick here if you DO NOT qualify for VAT exemption

# Hearing Aid - Mini Ear

AMC JH-906A

£17.26

This Product is NOT Available For VAT Relief

Quantity: |

Tell a friend about this product

## Description
You’ll be amazed at the Mini Ear hearing aid. Unlike many other hearing devices that are worn behind the ear, the Mini Ear fits discreetly and comfortable intoyour ear. And because everyone’s ears are different, it is provided with three different ear size tips to make sure it fits as comfortably as possible. You’ll forget it’s even there! Imagine being able to hear every sound again! Confusing conversations, missed dialogue on TV or radio – will become nothing but memories as the Super Mini Ear makes everything crystal clear. Supplied with two batteries, its own integral volume control, and a practical carry case. The Mini Ear is slightly larger than the Super Mini Ear.
## Mfg Info
AMC JH-906A Manufacturer Info • Other products
## Reviews Your Name (first name and one letter published) Email address (not published) Your rating Poor Fair Average Good Excellent Your Review Click the black square to submit your review.
## Reviews by Michelle Z Date Added: Tuesday 06 January, 2015 Review: this product is very good sound and comfortable!! worthy to use! Rating: by Michael F Date Added: Tuesday 24 March, 2015 Review: brilliant, tracy could not have been more professional and helpful would recommend. thanks Rating:

Copyright © 1999 - 2015 Active Mobility Centre Ltd. All Rights Reserved.
VAT Reg: 633348052 Company Reg: 3479911 Web development by Graith